use rocket::serde::json::Json;
use rocket::State;
use rocket::http::Status;

use crate::config::Config;
use crate::DbConn;
use crate::models;


#[post("/users/me/token", data = "<auth_request>")]
pub async fn create_auth_token(
    conn: DbConn,
    config: &State<Config>,
    auth_request: Json<models::AuthTokenRequest>
) -> Result<Json<models::Session>, models::ErrorResponse> {

    let session_duration = config.web_app.token_duration;

    let session = conn.run(move |c| {
        let user_info = models::LocalUser::get_user_by_creds(
            c,
            &auth_request.username,
            &auth_request.password
        )?;

        models::Session::new(c, &user_info, session_duration)
    }).await?;


    Ok(Json(session))
}

#[post("/users", data = "<user_request>")]
pub async fn create_user<'r>(conn: DbConn, user_request: Json<models::CreateUserRequest>) -> Result<Status, models::ErrorResponse> {
    // TODO: Check current user if any to check if user has permission to create users (with or without role)
    conn.run(|c| {
        models::LocalUser::create_user(&c, user_request.into_inner())
    }).await?;

    Ok(Status::Created)
}
